@@ -8,4 +8,6 @@ from spark_pipeline_framework_testing.test_runner import SparkPipelineFrameworkT
 def test_all(spark_session: SparkSession) -> None:
     data_dir: Path = Path(__file__).parent.joinpath('./')
 
-    SparkPipelineFrameworkTestRunner.run_tests(spark_session=spark_session, folder_path=data_dir)
+    SparkPipelineFrameworkTestRunner.run_tests(
+        spark_session=spark_session, folder_path=data_dir
+    )
